@@ -10,6 +10,9 @@
 #' the number will be repeated twice. The two numbers 
 #' indicate how many colors you will get in the result per 
 #' row and per column. Default is \code{c(10, 10)}.
+#' @param row_first enlarge rows first or enlarge columns 
+#' first? Default is TRUE. The results are almost the same, 
+#' so you do not need to change this.
 #' 
 #' @export
 #' @examples
@@ -24,15 +27,20 @@
 #' ggplot()+xlim(0, 10)+ylim(0, 5)+coord_fixed()+
 #' 	annotation_raster(mm, 
 #' 		xmin=0, xmax=10, ymin=0, ymax=5, interpolate=TRUE)
-enlarge_raster=function(x, n=c(10, 10)){
+enlarge_raster=function(x, n=c(10, 10), row_first=TRUE){
 	cla=class(x)[1]
 	stopifnot(cla %in% c("matrix", "raster"))
 	if (cla == "raster") x=as.matrix(x)
 	if (any(dim(x) < 1)) stop("x must have at least 1 row and 1 column.")
 	if (anyNA(x)) stop("x must have no NAs.")
 	if (length(n) == 1) n=rep(n, 2)
-	y=t(apply(x, 1, ENLARGE_COLOR_VECTOR, N=n[1]))
-	y=apply(y, 2, ENLARGE_COLOR_VECTOR, N=n[2])
+	if (row_first==TRUE){
+		y=t(apply(x, 1, ENLARGE_COLOR_VECTOR, N=n[1]))
+		y=apply(y, 2, ENLARGE_COLOR_VECTOR, N=n[2])
+	} else {
+		y=apply(x, 2, ENLARGE_COLOR_VECTOR, N=n[2])		
+		y=t(apply(y, 1, ENLARGE_COLOR_VECTOR, N=n[1]))
+	}
 	y
 }
 
